@@ -16,7 +16,8 @@ BEGIN { $fields = {
 	"tax_name" => new WWW::Shopify::Field::String(),
 	"tax_type" => new WWW::Shopify::Field::String(),
 	"tax_percentage" => new WWW::Shopify::Field::Float(),
-	"tax" => new WWW::Shopify::Field::Float()
+	"tax" => new WWW::Shopify::Field::Float(),
+	"country_id" => new WWW::Shopify::Field::Relation::Parent("WWW::Shopify::Model::Country")
 	
 }; }
 my $queries; sub queries { return $queries; }
