@@ -29,6 +29,8 @@ sub needs_login { return 1; }
 # Shopify recently just killed all their JSON apis for non-api stuff. Why? Who knows?
 # They're just delaying the inevitable.
 sub needs_form_encoding_create { return 1; }
+sub needs_form_encoding_update { return 1; }
+sub needs_form_encoding_delete { return 1; }
 
 eval(__PACKAGE__->generate_accessors); die $@ if $@;
 
