@@ -13,13 +13,14 @@ BEGIN { $fields = {
 	"accept_language" => new WWW::Shopify::Field::String(),
 	"browser_ip" => new WWW::Shopify::Field::String::IPAddress(),
 	"session_hash" => new WWW::Shopify::Field::String("[0-9A-F]{32}"),
-	"user_agent" => new WWW::Shopify::Field::String()
+	"user_agent" => new WWW::Shopify::Field::Text()
 }; }
 sub singular { return 'client_details'; }
 sub plural { return 'client_details'; }
 sub creatable { return undef; }
 sub updatable { return undef; }
 sub deletable { return undef; }
+sub is_single { 1; }
 
 eval(__PACKAGE__->generate_accessors); die $@ if $@;
 
