@@ -13,7 +13,8 @@ BEGIN { $fields = {
 	"name" => new WWW::Shopify::Field::String::Words(1),
 	"id" => new WWW::Shopify::Field::Identifier(),
 	"position" => new WWW::Shopify::Field::Int(1, 3),
-	"product_id" => new WWW::Shopify::Field::Relation::Parent('WWW::Shopify::Model::Product')
+	"product_id" => new WWW::Shopify::Field::Relation::Parent('WWW::Shopify::Model::Product'),
+	"values" => new WWW::Shopify::Field::Freeform::Array()
 }; }
 
 sub creation_minimal { return qw(name); }
