@@ -14,7 +14,12 @@ BEGIN { $fields = {
 	"target" => new WWW::Shopify::Field::String(),
 	"id" => new WWW::Shopify::Field::Identifier()
 }; }
-
+my $queries; sub queries { return $queries; }
+BEGIN { $queries = {
+	path => new WWW::Shopify::Query::Match('path'),
+	target => new WWW::Shopify::Query::Match('target'),
+	since_id => new WWW::Shopify::Query::LowerBound('id')
+}; }
 sub creation_minimal { return qw(path target); }
 sub creation_filled { return qw(id); }
 
