@@ -13,12 +13,14 @@ BEGIN { $fields = {
 	"name" => new WWW::Shopify::Field::String::Words(1),
 	"role" => new WWW::Shopify::Field::String::Enum(["main", "mobile", "unpublished"]),
 	"id" => new WWW::Shopify::Field::Identifier(),
-	"created_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00', max => 'now'),
-	"updated_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00', max => 'now')
+	"created_at" => new WWW::Shopify::Field::Date(),
+	"updated_at" => new WWW::Shopify::Field::Date(),
+	"assets" => new WWW::Shopify::Field::Relation::Many('WWW::Shopify::Model::Asset')
 }; }
 
 sub countable { return 0; }
 
+sub get_fields { return grep { $_ ne "assets" } keys(%$fields); }
 sub creation_minimal { return qw(name role); }
 sub creation_filled { return qw(id created_at); }
 sub update_filled { return qw(updated_at); }
