@@ -32,9 +32,9 @@ You can see an overview of the authentication workflow for a public app here: L<
 
 sub new { 
 	my $class = shift;
-	my ($shop_url, $api_key, $access_token) = @_;
-	die new WWW::Shopify::Exception("Can't create a shop without an api key.") unless $api_key;
-	my $self = $class->SUPER::new($shop_url);
+	my ($shop_url, $api_key, $access_token, $api_version) = @_;
+	my $self = $class->SUPER::new($shop_url,undef,undef,$api_version);
+	# This is an optional addition; it's not necessary.
 	$self->api_key($api_key);
 	$self->access_token($access_token);
 	$self->ua->default_header("X-Shopify-Access-Token" => $access_token);
@@ -67,14 +67,16 @@ When the shop doesn't have an access_token, this is what you should be redirecti
 
 use URI::Escape;
 sub authorize_url {
-	my ($self, $scope, $redirect) = (@_);
+	my ($self, $scope, $redirect, $nonce, $options) = @_;
 	my $hostname = $self->shop_url;
 	my %parameters = (
 		'client_id' => $self->api_key,	
 		'scope' => join(",", @$scope),
-		'redirect_uri' => $redirect
+		'redirect_uri' => $redirect,
+		($nonce ? ('state' => $nonce) : ()),
+		($options ? ('grant_options[]' => $options) : ())
 	);
-	return "https://$hostname/admin/oauth/authorize?" . join("&", map { "$_=" . uri_escape($parameters{$_}) } keys(%parameters));
+	return "https://$hostname/admin/oauth/authorize?" . join("&", map { my $key = $_; ref($parameters{$key}) ? (map { "$key=" . uri_escape($_) } @{$parameters{$key}}) : ("$key=" . uri_escape($parameters{$key})) } keys(%parameters));
 }
 
 =head2 scope_compare(@$scope1, @$scope2)
@@ -86,7 +88,7 @@ can be compared, returns -1, 0 or 1 as appropriate.
 =cut
 
 use Exporter 'import';
-our @EXPORT_OK = qw(scope_compare);
+our @EXPORT_OK = qw(scope_compare verify_install calc_hmac_install_signature);
 
 sub scope_compare {
 	my ($scope1, $scope2) = @_;
@@ -113,6 +115,39 @@ sub scope_compare {
 	return 0;
 }
 
+=head2 refresh_token($new_secret, $refresh_token)
+
+Refreshes a token.
+
+=cut 
+
+
+sub refresh_token {
+	my ($self, $new_secret, $refresh_token) = (@_);
+	
+	my $req = HTTP::Request->new(POST => "https://" . $self->shop_url . "/admin/oauth/access_token");
+  	$req->content_type('application/x-www-form-urlencoded');
+	my %parameters = (
+		'client_id' => $self->api_key,
+		'client_secret' => $new_secret,
+		'refresh_token' => $refresh_token,
+		'access_token' => $self->access_token
+	);
+	$req->content(join("&", map { "$_=" . uri_escape($parameters{$_}) } keys(%parameters)));
+	my $res;
+	my $success = undef;
+	for (my $i = 0; $i < 5 && !$success; ++$i) {
+		$res = $self->url_handler->request($req);
+		$success = $res->is_success();
+		sleep 1 unless $success;
+	}
+	die new WWW::Shopify::Exception("Unable to reach server for https://" . $self->shop_url . "/admin/oauth/access_token: " . $res->code() . ".\n" . $res->content) unless $res->is_success();
+	my $decoded = JSON::decode_json($res->content);
+	die new WWW::Shopify::Exception("Unable to refresh access token.") unless defined $decoded->{access_token};
+	return %{$decoded} if wantarray;
+	return $decoded->{access_token};
+}
+
 =head2 exchange_token($shared_secret, $code)
 
 When you have a temporary code, which you should get from authorize_url's redirect and you want to exchange it for a token, you call this.
@@ -134,16 +169,26 @@ sub exchange_token {
 	# If you go through the install too fast, Shopify will give you an access denied thing. So in that case, let's repeat until 
 	my $success = undef;
 	for (my $i = 0; $i < 5 && !$success; ++$i) {
-		$res = $self->ua->request($req);
+		$res = $self->url_handler->request($req);
 		$success = $res->is_success();
 		sleep 1 unless $success;
 	}
 	die new WWW::Shopify::Exception("Unable to reach server for https://" . $self->shop_url . "/admin/oauth/access_token: " . $res->code() . ".\n" . $res->content) unless $res->is_success();
 	my $decoded = JSON::decode_json($res->content);
 	die new WWW::Shopify::Exception("Unable to retrieve access token.") unless defined $decoded->{access_token};
+	return %{$decoded} if wantarray;
 	return $decoded->{access_token};
 }
 
+
+sub calc_hmac_install_signature { return WWW::Shopify::calc_hmac_login_signature(@_); }
+sub verify_install {
+	my ($shared_secret, $params) = @_;
+	return undef unless $params->{hmac};
+	my $hmac = ref($params->{hmac}) eq 'ARRAY' ? $params->{hmac}->[0] : $params->{hmac};
+	return calc_hmac_install_signature($shared_secret, $params) eq $hmac;
+}
+
 =head1 SEE ALSO
 
 L<WWW::Shopify::Item>, L<WWW::Shopify>
